==> lxqt-admin_0.16.0.orig.tar.xz: lxqt-admin-0.16.0/lxqt-admin-time/translations/lxqt-admin-time_ru.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="ru">
<context>
    <name>DateTime</name>
    <message>
        <location filename="../datetime.ui" line="23"/>
        <source>Time:</source>
        <translation>Время:</translation>
    </message>
    <message>
        <location filename="../datetime.ui" line="39"/>
        <source>HH:mm:ss</source>
        <translation>ЧЧ:мм:сс</translation>
    </message>
    <message>
        <location filename="../datetime.ui" line="53"/>
        <source>Date:</source>
        <translation>Дата:</translation>
    </message>
    <message>
        <location filename="../datetime.ui" line="70"/>
        <source>Enable network time synchronization (NTP)</source>
        <translation>Включить синхронизацию времени (NTP)</translation>
    </message>
    <message>
        <location filename="../datetime.ui" line="77"/>
        <source>RTC is in local time</source>
        <translation>RTC установлено на местное время</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <location filename="../fbsdtimedatectl.cpp" line="122"/>
        <source>lxqt-admin-time-helper</source>
        <translation>lxqt-admin-time-helper</translation>
    </message>
    <message>
        <location filename="../fbsdtimedatectl.cpp" line="123"/>
        <source>&lt;strong&gt;Action (%1) failed:&lt;/strong&gt;&lt;br/&gt;&lt;pre&gt;%2&lt;/pre&gt;</source>
        <translation>&lt;strong&gt;(%1) не удалось&lt;/strong&gt;&lt;br/&gt;&lt;pre&gt;%2&lt;/pre&gt;</translation>
    </message>
</context>
<context>
    <name>TimeAdminDialog</name>
    <message>
        <location filename="../timeadmindialog.cpp" line="45"/>
        <source>Time and date configuration</source>
        <translation>Настройки даты и времени</translation>
    </message>
    <message>
        <location filename="../timeadmindialog.cpp" line="51"/>
        <source>Date and time</source>
        <translation>Дата и время</translation>
    </message>
    <message>
        <location filename="../timeadmindialog.cpp" line="59"/>
        <source>Timezone</source>
        <translation>Часовой пояс</translation>
    </message>
    <message>
        <location filename="../timeadmindialog.cpp" line="120"/>
        <location filename="../timeadmindialog.cpp" line="130"/>
        <location filename="../timeadmindialog.cpp" line="137"/>
        <location filename="../timeadmindialog.cpp" line="147"/>
        <source>Error</source>
        <translation>Ошибка</translation>
    </message>
    <message>
        <location filename="../timeadmindialog.cpp" line="154"/>
        <source>Change RTC to be in localtime requires a reboot</source>
        <translation>Смена RTC на местное время требует перезагрузки</translation>
    </message>
    <message>
        <location filename="../timeadmindialog.cpp" line="154"/>
        <source>Change RTC to be in UTC requires a reboot</source>
        <translation>Смена RTC на UTC требует перезагрузки</translation>
    </message>
    <message>
        <location filename="../timeadmindialog.cpp" line="155"/>
        <source>Reboot required</source>
        <translation>Требуется перезагрузка</translation>
    </message>
</context>
<context>
    <name>Timezone</name>
    <message>
        <location filename="../timezone.ui" line="19"/>
        <source>Your current timezone:</source>
        <translation>Ваш текущий часовой пояс:</translation>
    </message>
    <message>
        <location filename="../timezone.ui" line="32"/>
        <source>Filter</source>
        <translation>Фильтр</translation>
    </message>
</context>
<context>
    <name>TimezonePage</name>
    <message>
        <location filename="../timezone.cpp" line="42"/>
        <source>None</source>
        <translation>Нет</translation>
    </message>
</context>
</TS>

==> lxqt-admin_1.4.0.orig.tar.xz: lxqt-admin-1.4.0/lxqt-admin-time/translations/lxqt-admin-time_ru.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="ru">
<context>
    <name>DateTime</name>
    <message>
        <location filename="../datetime.ui" line="23"/>
        <source>Time:</source>
        <translation>Время:</translation>
    </message>
    <message>
        <location filename="../datetime.ui" line="39"/>
        <source>HH:mm:ss</source>
        <translation>ЧЧ:мм:сс</translation>
    </message>
    <message>
        <location filename="../datetime.ui" line="53"/>
        <source>Date:</source>
        <translation>Дата:</translation>
    </message>
    <message>
        <location filename="../datetime.ui" line="70"/>
        <source>Enable network time synchronization (NTP)</source>
        <translation>Включить синхронизацию времени (NTP)</translation>
    </message>
    <message>
        <location filename="../datetime.ui" line="77"/>
        <source>RTC is in local time</source>
        <translation>RTC установлено на местное время</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <location filename="../fbsdtimedatectl.cpp" line="122"/>
        <location filename="../nosdtimedatectl.cpp" line="141"/>
        <source>lxqt-admin-time-helper</source>
        <translation>lxqt-admin-time-helper</translation>
    </message>
    <message>
        <location filename="../fbsdtimedatectl.cpp" line="123"/>
        <location filename="../nosdtimedatectl.cpp" line="142"/>
        <source>&lt;strong&gt;Action (%1) failed:&lt;/strong&gt;&lt;br/&gt;&lt;pre&gt;%2&lt;/pre&gt;</source>
        <translation>&lt;strong&gt;(%1) не удалось&lt;/strong&gt;&lt;br/&gt;&lt;pre&gt;%2&lt;/pre&gt;</translation>
    </message>
</context>
<context>
    <name>TimeAdminDialog</name>
    <message>
        <location filename="../timeadmindialog.cpp" line="45"/>
        <source>Time and date configuration</source>
        <translation>Настройки даты и времени</translation>
    </message>
    <message>
        <location filename="../timeadmindialog.cpp" line="51"/>
        <source>Date and time</source>
        <translation>Дата и время</translation>
    </message>
    <message>
        <location filename="../timeadmindialog.cpp" line="59"/>
        <source>Timezone</source>
        <translation>Часовой пояс</translation>
    </message>
    <message>
        <location filename="../timeadmindialog.cpp" line="122"/>
        <location filename="../timeadmindialog.cpp" line="132"/>
        <location filename="../timeadmindialog.cpp" line="139"/>
        <location filename="../timeadmindialog.cpp" line="149"/>
        <source>Error</source>
        <translation>Ошибка</translation>
    </message>
    <message>
        <location filename="../timeadmindialog.cpp" line="156"/>
        <source>Change RTC to be in localtime requires a reboot</source>
        <translation>Смена RTC на местное время требует перезагрузки</translation>
    </message>
    <message>
        <location filename="../timeadmindialog.cpp" line="156"/>
        <source>Change RTC to be in UTC requires a reboot</source>
        <translation>Смена RTC на UTC требует перезагрузки</translation>
    </message>
    <message>
        <location filename="../timeadmindialog.cpp" line="157"/>
        <source>Reboot required</source>
        <translation>Требуется перезагрузка</translation>
    </message>
</context>
<context>
    <name>Timezone</name>
    <message>
        <location filename="../timezone.ui" line="19"/>
        <source>Your current timezone:</source>
        <translation>Ваш текущий часовой пояс:</translation>
    </message>
    <message>
        <location filename="../timezone.ui" line="32"/>
        <source>Filter</source>
        <translation>Фильтр</translation>
    </message>
</context>
<context>
    <name>TimezonePage</name>
    <message>
        <location filename="../timezone.cpp" line="42"/>
        <source>None</source>
        <translation>Нет</translation>
    </message>
</context>
</TS>
